==> qtjambi-purchasing-debuginfo-windows-x64-5.15.18.jar: sources/QtJambiPurchasing/QInAppTransaction_shell.h <==
#ifndef QINAPPTRANSACTION_SHELL_H
#define QINAPPTRANSACTION_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtPurchasing/qinapptransaction.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtPurchasing/qinappproduct.h>
#include <QtJambi/RegistryAPI>


class QInAppTransaction_shell : public QInAppTransaction, public QtJambiShellInterface
{
public:
    QInAppTransaction_shell(qint32 status0, QInAppProduct* product1, QObject* parent2 = nullptr);
    ~QInAppTransaction_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    QString errorString() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QInAppTransaction::FailureReason failureReason() const override;
    void finalize() override;
    QString orderId() const override;
    QString platformProperty(const QString& propertyName0) const override;
    void timerEvent(QTimerEvent* event0) override;
    QDateTime timestamp() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QInAppTransaction_access : public QInAppTransaction
{
    jstring __qt_errorString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_failureReason(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_finalizeTransaction(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jstring __qt_orderId(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_platformProperty_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring propertyName0) const;
    jobject __qt_timestamp(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QINAPPTRANSACTION_SHELL_H

==> qtjambi-purchasing-debuginfo-windows-x64-5.15.20.jar: sources/QtJambiPurchasing/QInAppTransaction_shell.h <==
#ifndef QINAPPTRANSACTION_SHELL_H
#define QINAPPTRANSACTION_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtPurchasing/qinapptransaction.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtPurchasing/qinappproduct.h>
#include <QtJambi/RegistryAPI>


class QInAppTransaction_shell : public QInAppTransaction, public QtJambiShellInterface
{
public:
    QInAppTransaction_shell(qint32 status0, QInAppProduct* product1, QObject* parent2 = nullptr);
    ~QInAppTransaction_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    QString errorString() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QInAppTransaction::FailureReason failureReason() const override;
    void finalize() override;
    QString orderId() const override;
    QString platformProperty(const QString& propertyName0) const override;
    void timerEvent(QTimerEvent* event0) override;
    QDateTime timestamp() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QInAppTransaction_access : public QInAppTransaction
{
    jstring __qt_errorString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_failureReason_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_finalizeTransaction(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jstring __qt_orderId_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_platformProperty_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring propertyName0) const;
    jobject __qt_timestamp_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QINAPPTRANSACTION_SHELL_H
